AsyncCubitReactor<S, C extends Cubit<S>> class

Wrapper for a cubit that asynchronously react to its state changes May skip states if they happen during processing of a previous state change but will always react to the initial state and the most recent state

Constructors

AsyncCubitReactor(C create(), {required Future<void> onState(S)})
AsyncCubitReactor.value(C cubit, {required Future<void> onState(S)})

Properties

cubit → C
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited