AsyncCubitReactorState<T extends StateMachineState<T>, S, C extends Cubit<S>> class

A state machine state that waits for a cubit to change state and performs a transition based on the cubit state

Implemented types

Constructors

AsyncCubitReactorState(C create(), {required Future<T?> onState(AsyncCubitReactorStateContext<S, C>)})
AsyncCubitReactorState.value(C cubit, {required Future<T?> onState(AsyncCubitReactorStateContext<S, C>)})

Properties

active bool
getter/setter pair
cubit → C?
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

enter(void transition(T)) Future<void>
override
exit() Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stop() → void
Call this when you know you're done reacting to cubit state changes and are going to return a transition
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited