AsyncTransformerCubit<T, S> class
A cubit with state T that wraps another input cubit of state S and produces T fro S via an asynchronous transform closure The input cubit becomes 'owned' by the AsyncTransformerCubit and will be closed when the AsyncTransformerCubit closes.
Constructors
-
AsyncTransformerCubit(Cubit<
AsyncValue< input, {required Future<S> >AsyncValue< transform(S)})T> >
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
input
↔ Cubit<
AsyncValue< S> > -
getter/setter pair
- isClosed → bool
-
Whether the bloc is closed.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
→ AsyncValue<
T> -
The current state.
no setterinherited
-
stream
→ Stream<
AsyncValue< T> > -
The current stream of states.
no setterinherited
-
transform
↔ Future<
AsyncValue< Function(S)T> > -
getter/setter pair
Methods
-
addError(
Object error, [StackTrace? stackTrace]) → void -
Reports an
errorwhich triggersonErrorwith an optional StackTrace.inherited -
close(
) → Future< void> - Closes the instance. This method should be called when the instance is no longer needed. Once close is called, the instance can no longer be used.
-
emit(
AsyncValue< T> state) → void -
Updates the
stateto the providedstate.emitdoes nothing if thestatebeing emitted is equal to the currentstate.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onChange(
Change< AsyncValue< change) → voidT> > -
Called whenever a
changeoccurs with the givenchange. Achangeoccurs when a newstateis emitted.onChangeis called before thestateof thecubitis updated.onChangeis a great spot to add logging/analytics for a specificcubit.inherited -
onError(
Object error, StackTrace stackTrace) → void -
Called whenever an
erroroccurs and notifiesBlocObserver.onError.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited