BlocBusyWrapper<S> mixin

A wrapper for a bloc or cubit that wraps its state with a 'busy' state to easily add a means of ensuring blocs can report on when they are processing a change. Also provides methods to ensure only a single change is happening at once on the bloc.

Properties

changedState ↔ S?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isBusy bool
no setter
isClosed bool
Whether the bloc is closed.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state BlocBusyState<S>
The current state.
no setterinherited
stream Stream<BlocBusyState<S>>
The current stream of states.
no setterinherited

Methods

addError(Object error, [StackTrace? stackTrace]) → void
Reports an error which triggers onError with an optional StackTrace.
inherited
busy(Future<void> closure(void emit(S))) Future<void>
busyValue<T>(Future<T> closure(void emit(S))) Future<T>
changeState(S state) → void
close() Future<void>
Closes the instance. This method should be called when the instance is no longer needed. Once close is called, the instance can no longer be used.
inherited
emit(BlocBusyState<S> state) → void
Updates the state to the provided state. emit does nothing if the state being emitted is equal to the current state.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChange(Change<BlocBusyState<S>> change) → void
Called whenever a change occurs with the given change. A change occurs when a new state is emitted. onChange is called before the state of the cubit is updated. onChange is a great spot to add logging/analytics for a specific cubit.
inherited
onError(Object error, StackTrace stackTrace) → void
Called whenever an error occurs and notifies BlocObserver.onError.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited