BlocMapCubit<K, V, B extends BlocBase<V>> class abstract

Streaming container cubit that is a map from some immutable key to a some other cubit's output state. Output state for this container cubit is an immutable map of the key to the output state of the contained cubits.

K = Key type for the bloc map, used to look up some mapped cubit V = State type for the value, keys will look up values of this type B = Bloc/cubit type for the value, output states of type S

Mixed-in types

Constructors

BlocMapCubit()

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
Whether the bloc is closed.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state BlocMapState<K, V>
The current state.
no setterinherited
stream Stream<BlocMapState<K, V>>
The current stream of states.
no setterinherited

Methods

add(K key, B onCreate()) → void
addError(Object error, [StackTrace? stackTrace]) → void
Reports an error which triggers onError with an optional StackTrace.
inherited
addState(K key, V value) → void
close() Future<void>
Closes the instance. This method should be called when the instance is no longer needed. Once close is called, the instance can no longer be used.
emit(BlocMapState<K, V> state) → void
Updates the state to the provided state. emit does nothing if the state being emitted is equal to the current state.
inherited
entry(K key) → B?
getStateMap(BlocMapState<K, V> s) → IMap<K, V>
StateMapFollowable /////////////////////////
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChange(Change<BlocMapState<K, V>> change) → void
Called whenever a change occurs with the given change. A change occurs when a new state is emitted. onChange is called before the state of the cubit is updated. onChange is a great spot to add logging/analytics for a specific cubit.
inherited
onError(Object error, StackTrace stackTrace) → void
Called whenever an error occurs and notifies BlocObserver.onError.
inherited
registerFollower(StateMapFollower<BlocMapState<K, V>, K, V> follower) StreamSubscription<IMap<K, V>>
inherited
remove(K key) → void
toString() String
A string representation of this object.
inherited
unregisterFollower(StateMapFollower<BlocMapState<K, V>, K, V> follower) → void
inherited
update(K key, {required void onUpdate(B), B onCreate()?}) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited