BlocUpdater<B extends BlocBase, A> class

Constructors

BlocUpdater({required B create(A)})

Properties

bloc ↔ B?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(A? arguments) Future<B?>

Operators

operator ==(Object other) bool
The equality operator.
inherited