StateMapFollowable<S extends Object, K, V> class abstract mixin

Interface that allows a StateMapFollower to follow some other class's state changes

Implementers

Constructors

StateMapFollowable()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state → S
The current state.
no setterinherited
stream Stream<S>
The current stream of states.
no setterinherited

Methods

getStateMap(S state) → IMap<K, V>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerFollower(StateMapFollower<S, K, V> follower) StreamSubscription<IMap<K, V>>
toString() String
A string representation of this object.
inherited
unregisterFollower(StateMapFollower<S, K, V> follower) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited