StateMapFollower<S extends Object, K, V> mixin
Mixin that automatically keeps two blocs/cubits in sync with each other Useful for having a BlocMapCubit 'follow' the state of another input cubit. As the state of the input cubit changes, the BlocMapCubit can add/remove mapped Cubits that automatically process the input state reactively.
S = Input state type K = Key derived from elements of input state V = Value derived from elements of input state
Properties
Methods
-
close(
) → Future< void> - Closes the current instance. The returned future completes when the instance has been closed.
-
follow(
StateMapFollowable< S, K, V> followable) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeFromState(
K key) → void -
toString(
) → String -
A string representation of this object.
inherited
-
unfollow(
) → Future< void> -
updateState(
K key, V? oldValue, V newValue) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited